utils

package
v0.17.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 16, 2026 License: GPL-3.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func MatchOne

func MatchOne(pargs ...cobra.PositionalArgs) cobra.PositionalArgs

MatchOne checks for at least one valid PositionalArgs. Acts like an OR operator.

func MergeErr

func MergeErr(errs []error) error

MergeErr combines multiple errors into a single error, skipping nil entries. Returns nil if all errors are nil or the slice is empty.

func YAMLToJSON

func YAMLToJSON(file io.Reader) ([]byte, error)

YAMLToJSON converts the first YAML document in file to JSON. Returns an error if the reader contains more than one YAML document, as only the first would be validated and silently ignoring later documents can mask configuration mistakes.

Types

This section is empty.

Jump to