resources

package
v0.12.0-beta Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 11, 2026 License: GPL-3.0 Imports: 3 Imported by: 0

Documentation

Overview

Package resources exposes embedded application resources.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetProperty

func GetProperty(name Property) (string, error)

GetProperty returns the value of the named property from app.properties. Returns an error if the property is not found.

func ProfileTemplate

func ProfileTemplate() string

ProfileTemplate returns the embedded profile template content.

func RepoTemplate

func RepoTemplate() string

RepoTemplate returns the embedded repo template content.

Types

type Environment

type Environment string

Environment identifies the runtime environment the binary was built for.

const (
	EnvironmentDevelopment Environment = "development"
	EnvironmentPreview     Environment = "preview"
	EnvironmentProduction  Environment = "production"
)

type Property

type Property string

Property identifies a key in app.properties.

const (
	PropertyVersion     Property = "version"
	PropertyEnvironment Property = "environment"
)

Jump to