Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MatchOne ¶
func MatchOne(pargs ...cobra.PositionalArgs) cobra.PositionalArgs
MatchOne checks for at least one valid PositionalArgs. Acts like an OR operator.
func MergeErr ¶
MergeErr combines multiple errors into a single error, skipping nil entries. Returns nil if all errors are nil or the slice is empty.
func YAMLToJSON ¶
YAMLToJSON converts the first YAML document in file to JSON. Returns an error if the reader contains more than one YAML document, as only the first would be validated and silently ignoring later documents can mask configuration mistakes.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.