Documentation
¶
Overview ¶
Package resources exposes embedded application resources.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetProperty ¶
GetProperty returns the value of the named property from app.properties. Returns an error if the property is not found.
func ProfileTemplate ¶
func ProfileTemplate() string
ProfileTemplate returns the embedded profile template content.
func RepoTemplate ¶
func RepoTemplate() string
RepoTemplate returns the embedded repo template content.
Types ¶
type Environment ¶
type Environment string
Environment identifies the runtime environment the binary was built for.
const ( EnvironmentDevelopment Environment = "development" EnvironmentPreview Environment = "preview" EnvironmentProduction Environment = "production" )
Click to show internal directories.
Click to hide internal directories.