Documentation
¶
Overview ¶
Package resources exposes embedded application resources.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetProperty ¶
GetProperty returns the value of the named property from app.properties. Returns an error if the property is not found.
Types ¶
type Environment ¶
type Environment string
Environment identifies the runtime environment the binary was built for.
const ( EnvironmentDevelopment Environment = "development" EnvironmentPreview Environment = "preview" EnvironmentProduction Environment = "production" )
Click to show internal directories.
Click to hide internal directories.